C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\smallvec-a4457465a159bfb2.rmeta: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\smallvec-1.10.0\src\lib.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\libsmallvec-a4457465a159bfb2.rlib: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\smallvec-1.10.0\src\lib.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\smallvec-a4457465a159bfb2.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\smallvec-1.10.0\src\lib.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\smallvec-1.10.0\src\lib.rs:
